getrusage_thread

Function getrusage_thread 

pub fn getrusage_thread() -> Result<ResourceUsage>
Gets the resource usage measurements for the calling thread.

Note: Not supported on all platforms. May return ENOTSUP. On macOS and Windows not all fields are set, the unsupported fields are filled with zeroes. See ResourceUsage for more details.